@@ -12,7 +12,7 @@ Usage::
     client: ForecastQueryServiceClient = boto3.client("forecastquery")
     ```
 """
-from typing import Any, Dict, Type
+from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -24,7 +24,7 @@ __all__ = ("ForecastQueryServiceClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -40,7 +40,7 @@ class Exceptions:
 
 class ForecastQueryServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/forecastquery.html#ForecastQueryService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
     """
 
@@ -56,21 +56,21 @@ class ForecastQueryServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#generate_presigned_url)
         """
 
@@ -78,7 +78,7 @@ class ForecastQueryServiceClient(BaseClient):
         self,
         *,
         ForecastArn: str,
-        Filters: Dict[str, str],
+        Filters: Mapping[str, str],
         StartDate: str = None,
         EndDate: str = None,
         NextToken: str = None
@@ -86,6 +86,6 @@ class ForecastQueryServiceClient(BaseClient):
         """
         Retrieves a forecast for a single item, filtered by the supplied criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#query_forecast)
         """
