@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -49,7 +49,7 @@ _RequiredQueryForecastRequestRequestTypeDef = TypedDict(
     "_RequiredQueryForecastRequestRequestTypeDef",
     {
         "ForecastArn": str,
-        "Filters": Dict[str, str],
+        "Filters": Mapping[str, str],
     },
 )
 _OptionalQueryForecastRequestRequestTypeDef = TypedDict(
